! =================================================================================================================================
! MODULE       : constantes_var
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF        constantes_var module contains most constantes like pi, Earth radius, etc...
!!              and all externalized parameters except pft-dependent constants.
!!
!!\n DESCRIPTION: This module contains most constantes and the externalized parameters of ORCHIDEE which 
!!                are not pft-dependent.\n
!!                In this module, you can set the flag diag_qsat in order to detect the pixel where the
!!                temperature is out of range (look qsatcalc and dev_qsatcalc in qsat_moisture.f90).\n
!!                The Earth radius is approximated by the Equatorial radius.The Earth's equatorial radius a,
!!                or semi-major axis, is the distance from its center to the equator and equals 6,378.1370 km.
!!                The equatorial radius is often used to compare Earth with other planets.\n
!!                The meridional mean is well approximated by the semicubic mean of the two axe yielding 
!!                6367.4491 km or less accurately by the quadratic mean of the two axes about 6,367.454 km
!!                or even just the mean of the two axes about 6,367.445 km.\n
!!                This module is already USE in module constantes. Therefor no need to USE it seperatly except
!!                if the subroutines in module constantes are not needed.\n
!!                
!! RECENT CHANGE(S):
!!
!! REFERENCE(S)	: 
!! - Louis, Jean-Francois (1979), A parametric model of vertical eddy fluxes in the atmosphere. 
!! Boundary Layer Meteorology, 187-202.\n
!!
!! SVN          :
!! $HeadURL: $
!! $Date: 2015-02-22 16:18:16 +0100 (Sun, 22 Feb 2015) $
!! $Revision: 2555 $
!! \n
!_ ================================================================================================================================

MODULE constantes_var

  USE defprec

  IMPLICIT NONE
  !
  ! FLAGS 
  !
  TYPE control_type
    LOGICAL :: river_routing            !! activate river routing (true/false)
    LOGICAL :: hydrol_cwrr              !! activate 11 layers hydrolgy model (true/false)
    LOGICAL :: do_floodplains
    LOGICAL :: do_irrigation
    LOGICAL :: ok_sechiba               !! activate physic of the model (true/false)
    LOGICAL :: ok_co2                   !! activate photosynthesis (true/false)
    LOGICAL :: ok_stomate               !! activate carbon cycle (true/false)
    LOGICAL :: ok_dgvm                  !! activate dynamic vegetation (true/false)
    LOGICAL :: stomate_watchout         !! activate the creation of restart files for STOMATE even if STOMATE is not activated 
                                        !! (true/false)
    LOGICAL :: ok_pheno                 !! activate the calculation of lai using stomate rather than a prescription (true/false)
    LOGICAL :: do_land_use              !! ??? NOt clear why this is needed in the control structure
                                        !! Seems to duplicate ok_land_cover_change (previously lcchange)
    LOGICAL :: ok_inca                  !! activate biogenic volatile organic coumpounds ? (true/false)
    LOGICAL :: ok_leafage               !! activate leafage? (true/false)
    LOGICAL :: ok_radcanopy             !! use canopy radiative transfer model (true/false)
    LOGICAL :: ok_multilayer            !! use canopy radiative transfer model with multi-layers (true/false)
    LOGICAL :: ok_pulse_NOx             !! calculate NOx emissions with pulse (true/false)
    LOGICAL :: ok_bbgfertil_NOx         !! calculate NOx emissions with bbg fertilizing effect (true/false)
    LOGICAL :: ok_cropsfertil_NOx       !! calculate NOx emissions with fertilizers use (true/false)
    LOGICAL :: forest_management        !!
    LOGICAL :: do_new_snow_albedo       !! Use a new type of snow albedo compatible with new albedo schemes (true/false)
    LOGICAL :: ok_functional_allocation !! Use functional allocation rather than resource limited allocation (true/false)
    LOGICAL :: ok_cexchange             !! Use photosynthesis according to Friend et al 2010 (true/false)
    LOGICAL :: ok_hydrol_arch           !! Use hydraulic architecture to calculate supply of water for transpiration from the 
                                        !! leaves (true/false)
    LOGICAL :: ok_agricultural_harvest  !! Harvest the agricultural PFT's (true/false)
    LOGICAL :: ok_constant_mortality    !! Uses a prescribed constant mortality. If not activated, mortality is a function of 
                                        !! last year's NPP (true/false)
    LOGICAL :: ok_herbivory             !! allow herbivory (true/false)
    LOGICAL :: ok_land_cover_change     !! activate land cover change (true/false)
    LOGICAL :: ok_dofoco                !! Run a DOFOCO simulation (true/false)
                                        !! This flag overrides a number of other flags if set to TRUE.
    LOGICAL :: ok_daily_recruitment     !! Activate the daily recruitment
    LOGICAL :: ok_recruitment           !! Activate the recruitment
    LOGICAL :: ok_nenerbil              !! Activate the new energy budget scheme
    LOGICAL :: ok_gs_feedback           !! Activate water stress feedback on the stomatal conductance

    LOGICAL :: ok_joetzjer_hydro        !! Activate the detailled hydraulic architecture !tzjh 

 END TYPE control_type

  !-
  TYPE(control_type), SAVE :: control  !! Flags that (de)activate parts of the model
!$OMP THREADPRIVATE(control)
  LOGICAL, SAVE :: OFF_LINE_MODE = .FALSE.  !! ORCHIDEE detects if it is coupled with a GCM or 
                                            !! just use with one driver in OFF-LINE. (true/false)
!$OMP THREADPRIVATE(OFF_LINE_MODE)
  CHARACTER(LEN=80), SAVE     :: restname_in       = 'NONE'                 !! Input Restart files name for Sechiba component  
!$OMP THREADPRIVATE(restname_in)
  CHARACTER(LEN=80), SAVE     :: restname_out      = 'sechiba_rest_out.nc'  !! Output Restart files name for Sechiba component
!$OMP THREADPRIVATE(restname_out)
  CHARACTER(LEN=80), SAVE     :: stom_restname_in  = 'NONE'                 !! Input Restart files name for Stomate component
!$OMP THREADPRIVATE(stom_restname_in)
  CHARACTER(LEN=80), SAVE     :: stom_restname_out = 'stomate_rest_out.nc'  !! Output Restart files name for Stomate component
!$OMP THREADPRIVATE(stom_restname_out)

  !
  ! DEBUG
  !
  INTEGER(i_std), SAVE        :: test_pft = 2                               !! tzj Number of PFT for which detailed output 
                                                                            !! is written to the output file. If set > 26 no extra
                                                                            !! output is written



!$OMP THREADPRIVATE(test_pft)
  INTEGER(i_std), SAVE        :: test_grid                                  !! Number of the grid square for which detailed output 
                                                                            !! is written to the output file. 
!$OMP THREADPRIVATE(test_grid)
  INTEGER, SAVE :: printlev=1       !! Standard level for text output [0, 1, 2, 3]
!$OMP THREADPRIVATE(printlev)

  !
  ! TIME
  !
  REAL(r_std), SAVE :: one_day  !! One day in seconds (s)
!$OMP THREADPRIVATE(one_day)
  REAL(r_std), SAVE :: one_year !! One year in seconds (s)
!$OMP THREADPRIVATE(one_year)
  REAL(r_std), PARAMETER :: one_hour = 3600.0  !! One hour in seconds (s)

  ! TIME STEP
  REAL(r_std)            :: dt_sechiba         !! Time step for in sechiba
!$OMP THREADPRIVATE(dt_sechiba)

  !
  ! SPECIAL VALUES 
  !
  INTEGER(i_std), PARAMETER :: undef_int = 999999999     !! undef integer for integer arrays (unitless)
  !-
  REAL(r_std), SAVE :: val_exp = 999999.                 !! Specific value if no restart value  (unitless)
!$OMP THREADPRIVATE(val_exp)
  REAL(r_std), PARAMETER :: undef = -9999.               !! Special value for stomate (unitless)
  !-
  REAL(r_std), PARAMETER :: min_sechiba = 1.E-8_r_std    !! Epsilon to detect a near zero floating point (unitless)
  REAL(r_std), PARAMETER :: undef_sechiba = 1.E+20_r_std !! The undef value used in SECHIBA (unitless)
  !-
  REAL(r_std), PARAMETER :: min_stomate = 1.E-8_r_std    !! Epsilon to detect a near zero floating point (unitless)
  REAL(r_std), PARAMETER :: large_value = 1.E33_r_std    !! some large value (for stomate) (unitless)


  !
  !  DIMENSIONING AND INDICES PARAMETERS  
  !
  INTEGER(i_std), PARAMETER :: ibare_sechiba = 1 !! Index for bare soil in Sechiba (unitless)
  INTEGER(i_std), PARAMETER :: ivis = 1          !! index for albedo in visible range (unitless)
  INTEGER(i_std), PARAMETER :: inir = 2          !! index for albeod i near-infrared range (unitless) 
  INTEGER(i_std), PARAMETER :: n_spectralbands=2  !! number of spectral bands
  INTEGER(i_std), PARAMETER :: nnobio = 1        !! Number of other surface types: land ice (lakes,cities, ...) (unitless)
  INTEGER(i_std), PARAMETER :: iice = 1          !! Index for land ice (see nnobio) (unitless)
  !-
  !! Soil
  INTEGER(i_std), PARAMETER :: classnb = 9       !! Levels of soil colour classification (unitless)
  !-
  INTEGER(i_std), PARAMETER :: nleafages = 4     !! leaf age discretisation ( 1 = no discretisation )(unitless)
  !-
  !! litter fractions: indices (unitless)
  INTEGER(i_std), PARAMETER :: ileaf = 1         !! Index for leaf compartment (unitless)
  INTEGER(i_std), PARAMETER :: isapabove = 2     !! Index for sapwood above compartment (unitless)
  INTEGER(i_std), PARAMETER :: isapbelow = 3     !! Index for sapwood below compartment (unitless)
  INTEGER(i_std), PARAMETER :: iheartabove = 4   !! Index for heartwood above compartment (unitless)
  INTEGER(i_std), PARAMETER :: iheartbelow = 5   !! Index for heartwood below compartment (unitless)
  INTEGER(i_std), PARAMETER :: iroot = 6         !! Index for roots compartment (unitless)
  INTEGER(i_std), PARAMETER :: ifruit = 7        !! Index for fruits compartment (unitless)
  INTEGER(i_std), PARAMETER :: icarbres = 8      !! Index for reserve compartment (unitless)
  INTEGER(i_std), PARAMETER :: ilabile = 9       !! Index for reserve compartment (unitless) 
  INTEGER(i_std), PARAMETER :: nparts = 9        !! Number of biomass compartments (unitless)
  !-
  !! indices for assimilation parameters 
  INTEGER(i_std), PARAMETER :: ivcmax = 1        !! Index for vcmax (assimilation parameters) (unitless)
  INTEGER(i_std), PARAMETER :: npco2 = 1         !! Number of assimilation parameters (unitless)
  !-
  !! trees and litter: indices for the parts of heart-
  !! and sapwood above and below the ground 
  INTEGER(i_std), PARAMETER :: iabove = 1       !! Index for above part (unitless)
  INTEGER(i_std), PARAMETER :: ibelow = 2       !! Index for below part (unitless)
  INTEGER(i_std), PARAMETER :: nlevs = 2        !! Number of levels for trees and litter (unitless)
  !-
  !! litter: indices for metabolic and structural part
  INTEGER(i_std), PARAMETER :: imetabolic = 1   !! Index for metabolic litter (unitless)
  INTEGER(i_std), PARAMETER :: istructural = 2  !! Index for structural litter (unitless)
  INTEGER(i_std), PARAMETER :: iwoody = 3       !! Index for woody litter (unitless)
  INTEGER(i_std), PARAMETER :: nlitt = 3        !! Number of levels for litter compartments (unitless)
  !-
  !! carbon pools: indices
  INTEGER(i_std), PARAMETER :: iactive = 1      !! Index for active carbon pool (unitless)
  INTEGER(i_std), PARAMETER :: islow = 2        !! Index for slow carbon pool (unitless)
  INTEGER(i_std), PARAMETER :: ipassive = 3     !! Index for passive carbon pool (unitless)
  INTEGER(i_std), PARAMETER :: ncarb = 3        !! Number of soil carbon pools (unitless)
  !-
  !! For isotopes and nitrogen
  INTEGER(i_std), PARAMETER :: nelements = 1    !! Number of isotopes considered
  INTEGER(i_std), PARAMETER :: icarbon = 1      !! Index for carbon 
  !
  !! Indices used for analytical spin-up
  INTEGER(i_std), PARAMETER :: nbpools = 9              !! Total number of carbon pools (unitless)
  INTEGER(i_std), PARAMETER :: istructural_above = 1    !! Index for structural litter above (unitless)
  INTEGER(i_std), PARAMETER :: istructural_below = 2    !! Index for structural litter below (unitless)
  INTEGER(i_std), PARAMETER :: imetabolic_above = 3     !! Index for metabolic litter above (unitless)
  INTEGER(i_std), PARAMETER :: imetabolic_below = 4     !! Index for metabolic litter below (unitless)
  INTEGER(i_std), PARAMETER :: iwoody_above = 5         !! Index for woody litter above (unitless)
  INTEGER(i_std), PARAMETER :: iwoody_below = 6         !! Index for woody litter below (unitless)
  INTEGER(i_std), PARAMETER :: iactive_pool = 7         !! Index for active carbon pool (unitless)
  INTEGER(i_std), PARAMETER :: islow_pool   = 8         !! Index for slow carbon pool (unitless)
  INTEGER(i_std), PARAMETER :: ipassive_pool = 9        !! Index for passive carbon pool (unitless)
  !
  !! Indices for orphan fluxes
  INTEGER(i_std), PARAMETER :: norphans = 8             !! Total number of orphan fluxes (unitless)
  INTEGER(i_std), PARAMETER :: ivegold = 1              !! Index for veget_max before LCC
  INTEGER(i_std), PARAMETER :: ivegnew = 2              !! Index for veget_max before LCC (includes veget_max of orphan fluxes)
  INTEGER(i_std), PARAMETER :: igpp = 3                 !! Index for gpp_daily
  INTEGER(i_std), PARAMETER :: ico2bm = 4               !! Index for co2_to_bm
  INTEGER(i_std), PARAMETER :: irmain = 5               !! Index for maintenance respiration
  INTEGER(i_std), PARAMETER :: irgrow = 6               !! Index for growth respiration
  INTEGER(i_std), PARAMETER :: inpp = 7                 !! Index for npp_daily
  INTEGER(i_std), PARAMETER :: irhet = 8                !! Index for total heterotrophic respiration
  !
  !! Indices for circumference classes (output)
  INTEGER(i_std), PARAMETER :: ic02 = 1                 !! circumeference < 0.2 m
  INTEGER(i_std), PARAMETER :: ic04 = 2                 !! 0.2 < circ < 0.4
  INTEGER(i_std), PARAMETER :: ic06 = 3                 !! 0.4 < circ < 0.6
  INTEGER(i_std), PARAMETER :: ic08 = 4                 !! 0.6 < circ < 0.8
  INTEGER(i_std), PARAMETER :: ic10 = 5                 !! 0.8 < circ < 1.0
  INTEGER(i_std), PARAMETER :: ic12 = 6                 !! 1.0 < circ < 1.2
  INTEGER(i_std), PARAMETER :: ic14 = 7                 !! 1.2 < circ < 1.4
  INTEGER(i_std), PARAMETER :: ic16 = 8                 !! 1.4 < circ < 1.6
  INTEGER(i_std), PARAMETER :: ic18 = 9                 !! 1.6 < circ < 1.8
  INTEGER(i_std), PARAMETER :: ic20 = 10                !! 1.8 < circ < 2.0
  INTEGER(i_std), PARAMETER :: ic222 = 11               !! circ > 2 m
  INTEGER(i_std), PARAMETER :: icpo = 12                !! poles, circumference <0.235 m
  INTEGER(i_std), PARAMETER :: icsw = 13                !! small wood, 0.235 < circ < 0.705
  INTEGER(i_std), PARAMETER :: icmw = 14                !! medium wood, 0.705 < circ < 1.175
  INTEGER(i_std), PARAMETER :: iclw = 15                !! large wood, 1.175 < circ 

  !
  ! These next sets of parameters are now used for both circ_class_kill and
  ! for the harvest_pool.  One source of confusion is what to do with trees that
  ! die from self-thinning or forest dieoffs.  These happen in all forests, regardless
  ! of management strategy.  I decided to put death of this kind into ifm_none, since
  ! it is the only type of mortality found in an unmanaged forest.  If the mortality
  ! does not kill the whole forest (e.g. self thinning), it goes into icut_thin.  If it
  ! does (forest dieoff), it goes into icut_clear.  The biomass is killed in lpj_gap.

  !! Indices used for forest management strategies
  INTEGER(i_std), PARAMETER :: nfm_types = 6             !! The total number of forest management strategies we can use
  INTEGER(i_std), PARAMETER :: ifm_none = 1              !! No human intervention in the forests.
  INTEGER(i_std), PARAMETER :: ifm_thin = 2              !! Regular thinning and harvesting of wood based on RDI.
  INTEGER(i_std), PARAMETER :: ifm_cop = 3               !! Coppicing for fuelwood.
  INTEGER(i_std), PARAMETER :: ifm_src = 4               !! Short rotation coppices for biomass production.
  INTEGER(i_std), PARAMETER :: ifm_crop = 5              !! Crop harvest
  INTEGER(i_std), PARAMETER :: ifm_grass = 6             !! Grazing or cutting 
  !! Indices used for harvest pools
  INTEGER(i_std), PARAMETER :: ncut_times = 9            !! The total number of times when trees are cut and wood harvested.
  INTEGER(i_std), PARAMETER :: icut_clear = 1            !! A clearcut where all biomass is removed.
  INTEGER(i_std), PARAMETER :: icut_thin = 2             !! Thinning of biomass to reduce the number of trees.
  INTEGER(i_std), PARAMETER :: icut_lcc_wood = 3         !! Wood harvest following land cover change (LCC)
  INTEGER(i_std), PARAMETER :: icut_lcc_res = 4          !! Site clearing, removal of the stumps and branches following LCC
  INTEGER(i_std), PARAMETER :: icut_crop = 5             !! Crop harvest
  INTEGER(i_std), PARAMETER :: icut_grass = 6            !! Grazing or cutting
  INTEGER(i_std), PARAMETER :: icut_cop1 = 7             !! The first coppice cut
  INTEGER(i_std), PARAMETER :: icut_cop2 = 8             !! The second (and subsequent) coppice cut
  INTEGER(i_std), PARAMETER :: icut_cop3 = 9             !! The last coppice cut (only for SRC)

  !! Indices used to define the product pools
  INTEGER(i_std), PARAMETER :: nshort = 1                !! Length in years of the short-lived product pool (GE 1)
  INTEGER(i_std), PARAMETER :: nmedium = 10              !! Length in years of the medium-lived product pool (GT 4)
  INTEGER(i_std), PARAMETER :: nlong = 100               !! Length in years of the long-lived product pool (GT 4)

  !! Indices used to check the mass balance closure
  INTEGER(i_std), PARAMETER :: nmbcomp = 5               !! The total nomber of components in our mass balance check
  INTEGER(i_std), PARAMETER :: iatm2land = 1             !! atmosphere to land fluxes such as GPP and co2_2_bm
  INTEGER(i_std), PARAMETER :: iland2atm = 2             !! land to atmosphere fluxes such as Rh, Ra and product decomposition
  INTEGER(i_std), PARAMETER :: ilat2out = 3              !! outgoing lateral flux i.e. DOC leaching for the litter routine
  INTEGER(i_std), PARAMETER :: ilat2in = 4               !! incoming lateral flux i.e. N deposition for the land
  INTEGER(i_std), PARAMETER :: ipoolchange = 5           !! change in pool size i.e. change in biomass

  !! Indices used for warning tracking
  INTEGER(i_std), PARAMETER :: nwarns = 1                !! The total number of warnings we track
  INTEGER(i_std), PARAMETER :: iwphoto = 1               !! A warning about division by zero in photosynthesis 
  !
  ! NUMERICAL AND PHYSICS CONSTANTS
  !

  !-
  ! 1. Mathematical and numerical constants
  !-
  REAL(r_std), PARAMETER :: pi = 3.141592653589793238   !! pi souce : http://mathworld.wolfram.com/Pi.html (unitless)
  REAL(r_std), PARAMETER :: euler = 2.71828182845904523 !! e source : http://mathworld.wolfram.com/e.html (unitless)
  REAL(r_std), PARAMETER :: zero = 0._r_std             !! Numerical constant set to 0 (unitless)
  REAL(r_std), PARAMETER :: undemi = 0.5_r_std          !! Numerical constant set to 1/2 (unitless)
  REAL(r_std), PARAMETER :: un = 1._r_std               !! Numerical constant set to 1 (unitless)
  REAL(r_std), PARAMETER :: moins_un = -1._r_std        !! Numerical constant set to -1 (unitless)
  REAL(r_std), PARAMETER :: deux = 2._r_std             !! Numerical constant set to 2 (unitless)
  REAL(r_std), PARAMETER :: trois = 3._r_std            !! Numerical constant set to 3 (unitless)
  REAL(r_std), PARAMETER :: quatre = 4._r_std           !! Numerical constant set to 4 (unitless)
  REAL(r_std), PARAMETER :: cinq = 5._r_std             !![DISPENSABLE] Numerical constant set to 5 (unitless)
  REAL(r_std), PARAMETER :: six = 6._r_std              !![DISPENSABLE] Numerical constant set to 6 (unitless)
  REAL(r_std), PARAMETER :: huit = 8._r_std             !! Numerical constant set to 8 (unitless)
  REAL(r_std), PARAMETER :: mille = 1000._r_std         !! Numerical constant set to 1000 (unitless)

  !-
  ! 2 . Physics
  !-
  REAL(r_std), PARAMETER :: R_Earth = 6378000.              !! radius of the Earth : Earth radius ~= Equatorial radius (m)
  REAL(r_std), PARAMETER :: mincos  = 0.0001                !! Minimum cosine value used for interpolation (unitless) 
  REAL(r_std), PARAMETER :: pb_std = 1013.                  !! standard pressure (hPa)
  REAL(r_std), PARAMETER :: ZeroCelsius = 273.15            !! Freezing point (K)
  REAL(r_std), PARAMETER :: tp_00 = 273.15                  !! 0 degre Celsius in degre Kelvin (K)
  REAL(r_std), PARAMETER :: chalsu0 = 2.8345E06             !! Latent heat of sublimation (J.kg^{-1})
  REAL(r_std), PARAMETER :: chalev0 = 2.5008E06             !! Latent heat of evaporation (J.kg^{-1}) 
  REAL(r_std), PARAMETER :: chalfu0 = chalsu0-chalev0       !! Latent heat of fusion (J.kg^{-1}) 
  REAL(r_std), PARAMETER :: c_stefan = 5.6697E-8            !! Stefan-Boltzman constant (W.m^{-2}.K^{-4})
  REAL(r_std), PARAMETER :: cp_air = 1004.675               !! Specific heat of dry air (J.kg^{-1}.K^{-1}) 
  REAL(r_std), PARAMETER :: cte_molr = 287.05               !! Specific constant of dry air (kg.mol^{-1}) 
  REAL(r_std), PARAMETER :: kappa = cte_molr/cp_air         !! Kappa : ratio between specific constant and specific heat 
                                                            !! of dry air (unitless)
  REAL(r_std), PARAMETER :: msmlr_air = 28.964E-03          !! Molecular weight of dry air (kg.mol^{-1})
  REAL(r_std), PARAMETER :: msmlr_h2o = 18.02E-03           !! Molecular weight of water vapor (kg.mol^{-1}) 
  REAL(r_std), PARAMETER :: cp_h2o = &                      !! Specific heat of water vapor (J.kg^{-1}.K^{-1}) 
       & cp_air*(quatre*msmlr_air)/( 3.5_r_std*msmlr_h2o) 
  REAL(r_std), PARAMETER :: cte_molr_h2o = cte_molr/quatre  !! Specific constant of water vapor (J.kg^{-1}.K^{-1}) 
  REAL(r_std), PARAMETER :: retv = msmlr_air/msmlr_h2o-un   !! Ratio between molecular weight of dry air and water 
                                                            !! vapor minus 1(unitless)  
  REAL(r_std), PARAMETER :: rvtmp2 = cp_h2o/cp_air-un       !! Ratio between specific heat of water vapor and dry air
                                                            !! minus 1 (unitless)
  REAL(r_std), PARAMETER :: rho_h2o= 0.9991_r_std           !! Density of water at 15°C (g cm-3)                       
  REAL(r_std), PARAMETER :: cepdu2 = (0.1_r_std)**2         !! Squared wind shear (m^2.s^{-2}) 
  REAL(r_std), PARAMETER :: ct_karman = 0.35_r_std          !! Van Karmann Constant (unitless)
  REAL(r_std), PARAMETER :: cte_grav = 9.80665_r_std        !! Acceleration of the gravity (m.s^{-2})
  REAL(r_std), PARAMETER :: pa_par_hpa = 100._r_std         !! Transform pascal into hectopascal (unitless)
  REAL(r_std), PARAMETER :: RR = 8.314                      !! Ideal gasconstant (J.mol^{-1}.K^{-1})
  REAL(r_std), PARAMETER :: Sct = 1370.                     !! Solar constant (W.m^{-2}) 


  !-
  ! 3. Climatic constants
  !-
  !! Constantes of the Louis scheme 
  REAL(r_std), PARAMETER :: cb = 5._r_std         !! Constant of the Louis scheme (unitless);
                                                  !! reference to Louis (1979)
  REAL(r_std), PARAMETER :: cc = 5._r_std         !! Constant of the Louis scheme (unitless);
                                                  !! reference to Louis (1979)
  REAL(r_std), PARAMETER :: cd = 5._r_std         !! Constant of the Louis scheme (unitless);
                                                  !! reference to Louis (1979)
  !-
  REAL(r_std), PARAMETER :: rayt_cste = 125.      !! Constant in the computation of surface resistance (W.m^{-2})
  REAL(r_std), PARAMETER :: defc_plus = 23.E-3    !! Constant in the computation of surface resistance (K.W^{-1})
  REAL(r_std), PARAMETER :: defc_mult = 1.5       !! Constant in the computation of surface resistance (K.W^{-1})

  !-
  ! 4. Soil thermodynamics constants
  !-
  ! Look at constantes_soil.f90


  !-
  ! 5. Unit convertions
  !-
  REAL(r_std), PARAMETER :: ha_to_m2 = 0.0001       !! Conversion from hectares (forestry) to m2 (rest of the code)
  REAL(r_std), PARAMETER :: m2_to_ha = 10000.       !! Conversion from m2 to hectares
  REAL(r_std), PARAMETER :: m_to_cm = 100.          !! Conversion from m to cm
  REAL(r_std), PARAMETER :: peta_to_unit = 1.0E15   !! Convert Peta to unit
  REAL(r_std), PARAMETER :: tera_to_unit = 1.0E12   !! Convert Tera to unit 
  REAL(r_std), PARAMETER :: giga_to_unit = 1.0E09   !! Convert Giga to unit
  REAL(r_std), PARAMETER :: mega_to_unit = 1.0E06   !! Convert Mega to unit
  REAL(r_std), PARAMETER :: kilo_to_unit = 1.0E03   !! Convert Kilo to unit
  REAL(r_std), PARAMETER :: centi_to_unit = 1.0E02  !! Convert centi to unit
  REAL(r_std), PARAMETER :: milli_to_unit = 1.0E-03 !! Convert milli to unit
  REAL(r_std), PARAMETER :: carbon_to_kilo = 2.0E-03!! Convert g carbon to kilo biomass

  !
  ! OPTIONAL PARTS OF THE MODEL
  !
  LOGICAL, SAVE     :: long_print = .false.       !! To set for more printing
!$OMP THREADPRIVATE(long_print)
  LOGICAL,PARAMETER :: diag_qsat = .TRUE.         !! One of the most frequent problems is a temperature out of range
                                                  !! we provide here a way to catch that in the calling procedure. 
                                                  !! (from Jan Polcher)(true/false) 
  LOGICAL, SAVE     :: almaoutput                 !! Selects the type of output for the model.(true/false)
                                                  !! Value is read from run.def in intersurf_history
!$OMP THREADPRIVATE(almaoutput)

  !
  ! DIVERSE
  !
  CHARACTER(LEN=100), SAVE :: stomate_forcing_name='NONE'  !! NV080800 Name of STOMATE forcing file (unitless)
                                                           ! Compatibility with Nicolas Viovy driver.
!$OMP THREADPRIVATE(stomate_forcing_name)
  CHARACTER(LEN=100), SAVE :: stomate_Cforcing_name='NONE' !! NV080800 Name of soil forcing file (unitless)
                                                           ! Compatibility with Nicolas Viovy driver.
!$OMP THREADPRIVATE(stomate_Cforcing_name)
  INTEGER(i_std), SAVE :: forcing_id                 !! Index of the forcing file (unitless)
!$OMP THREADPRIVATE(forcing_id)




                         !------------------------!
                         !  SECHIBA PARAMETERS    !
                         !------------------------!
 

  !
  ! GLOBAL PARAMETERS   
  !
  REAL(r_std), SAVE :: min_wind = 0.1      !! The minimum wind (m.s^{-1})
!$OMP THREADPRIVATE(min_wind)
  REAL(r_std), SAVE :: snowcri = 1.5       !! Sets the amount above which only sublimation occures (kg.m^{-2})
!$OMP THREADPRIVATE(snowcri)
  INTEGER(i_std), SAVE        :: jnlvls = 1                                 !! Number of levels in the multilayer energy budget scheme

  !
  ! FLAGS ACTIVATING SUB-MODELS
  !
! +++CHECK+++
! Logical flags that affect the flow of the code should 
! be stored in the control-structure

!!$ Moved to control-structure!!$ Moved to control-structure
!!$  LOGICAL, SAVE :: ok_herbivores = .FALSE.     !! flag to activate herbivores (true/false)
!!$ !$OMP THREADPRIVATE(ok_herbivores)
!!$  LOGICAL, SAVE :: lpj_gap_const_mort = .TRUE. !! constant moratlity (true/false)
!!$ !$OMP THREADPRIVATE(lpj_gap_const_mort)
!!$  LOGICAL, SAVE :: lcchange = .FALSE.      !! Land cover change flag (true/false)
!!$ !$OMP THREADPRIVATE(lcchange)
!!$ LOGICAL, SAVE :: harvest_agri = .TRUE.       !! flag to harvest aboveground biomass from agricultural PFTs)(true/false)
!!$ !$OMP THREADPRIVATE(harvest_agri)

  LOGICAL, SAVE :: treat_expansion = .FALSE.   !! Do we treat PFT expansion across a grid point after introduction? (true/false)
!$OMP THREADPRIVATE(treat_expansion)
  LOGICAL, SAVE :: disable_fire = .FALSE.      !! flag that disable fire (true/false)
!$OMP THREADPRIVATE(disable_fire)
  LOGICAL, SAVE :: spinup_analytic = .FALSE.   !! Flag to activate analytical resolution for spinup (true/false)
!$OMP THREADPRIVATE(spinup_analytic)

  !
  ! CONFIGURATION VEGETATION
  !
  LOGICAL, SAVE :: agriculture = .TRUE.    !! allow agricultural PFTs (true/false)
!$OMP THREADPRIVATE(agriculture)
  LOGICAL, SAVE :: impveg = .FALSE.        !! Impose vegetation ? (true/false)
!$OMP THREADPRIVATE(impveg)
  LOGICAL, SAVE :: impsoilt = .FALSE.      !! Impose soil ? (true/false)
!$OMP THREADPRIVATE(impsoilt)
  LOGICAL, SAVE :: read_lai = .FALSE.      !! Flag to read a map of LAI if STOMATE is not activated (true/false)
!$OMP THREADPRIVATE(read_lai)
  LOGICAL, SAVE :: old_lai = .FALSE.       !! Flag for the old LAI map interpolation (SHOULD BE DROPED ??)(true/false)
!$OMP THREADPRIVATE(old_lai)
  LOGICAL, SAVE :: old_veget = .FALSE.     !! Flag to use the old vegetation Map interpolation (SHOULD BE DROPED ?)(true/false)
!$OMP THREADPRIVATE(old_veget)
  LOGICAL, SAVE :: land_use = .TRUE.       !! flag to account or not for Land Use  (true/false)
!$OMP THREADPRIVATE(land_use)
  LOGICAL, SAVE :: veget_reinit = .TRUE.   !! To change LAND USE file in a run. (true/false)
!$OMP THREADPRIVATE(veget_reinit)
! +++++++++++

  !
  ! PARAMETERS USED BY BOTH HYDROLOGY MODELS
  !
  REAL(r_std), SAVE :: max_snow_age = 50._r_std !! Maximum period of snow aging (days)
!$OMP THREADPRIVATE(max_snow_age)
  REAL(r_std), SAVE :: snow_trans = 0.3_r_std   !! Transformation time constant for snow (m), reduced from the value 0.3 (04/07/2016) tzjwb
!$OMP THREADPRIVATE(snow_trans)
  REAL(r_std), SAVE :: sneige                   !! Lower limit of snow amount (kg.m^{-2})
!$OMP THREADPRIVATE(sneige)
  REAL(r_std), SAVE :: maxmass_glacier = 3000.  !! The maximum mass of a glacier (kg.m^{-2})
!$OMP THREADPRIVATE(maxmass_glacier)
! tzjwb
  REAL(r_std), SAVE :: maxmass_snow = 3000.  !! The maximum mass of a snow (kg.m^{-2})
!$OMP THREADPRIVATE(maxmass_snow)
  REAL(r_std), SAVE :: vpd_k1 = 1
  REAL(r_std), SAVE :: vpd_b1 = 0
  REAL(r_std), SAVE :: ra_max = 1.e-4
  REAL(r_std), SAVE :: maint_var=2.5 
  REAL(r_std), SAVE :: cut_limit=0.8
  REAL(r_std), SAVE :: psileaf_fac=1.0
  REAL(r_std), SAVE :: psiroot_fac=1.0
  REAL(r_std), SAVE :: rec_factor=1.0
  REAL(r_std), SAVE :: day_threshold = 20
  REAL(r_std), SAVE :: vertical_limit=1
  REAL(r_std), SAVE :: minpsi=-3.0
  REAL(r_std), SAVE :: relax_counter = 0
  REAL(r_std), SAVE :: psi_soil_min = -3
  REAL(r_std), SAVE :: plc_threshold = 50
  REAL(r_std), SAVE :: min_kfactroot = 1.3
  REAL(r_std), SAVE :: coef_max_drain = 0.8 
  REAL(r_std), SAVE :: yyt_flag_mortality=1
  REAL(r_std), SAVE :: nicolas_solution=0
  REAL(r_std), SAVE :: pres_kfact=0
  REAL(r_std), SAVE :: pres_soil_potential_min = -2.5
  REAL(r_std), SAVE :: supply_flag=1
  REAL(r_std), SAVE :: precip_bias_correct=1
  REAL(r_std), SAVE :: st_cut_fac=3.0
  REAL(r_std), SAVE :: pleaf_k=-1.46
  REAL(r_std), SAVE :: pleaf_b=-1.738
  REAL(r_std), SAVE :: proot_k=-1.67
  REAL(r_std), SAVE :: proot_b=0.33
  REAL(r_std), SAVE :: hum_leaf=0.05
  REAL(r_std), SAVE :: hum_root=0.05
  REAL(r_std), SAVE :: hum_plc=5
  !! Heat capacity
  REAL(r_std), PARAMETER :: capa_ice = 2.228*1.E3       !! Heat capacity of ice (J/kg/K)
  REAL(r_std), SAVE      :: so_capa_ice                 !! Heat capacity of saturated frozen soil (J/K/m3)
!$OMP THREADPRIVATE(so_capa_ice)
  REAL(r_std), PARAMETER :: rho_water = 1000.           !! Density of water (kg/m3)
  REAL(r_std), PARAMETER :: rho_ice = 920.              !! Density of ice (kg/m3)

  !! Thermal conductivities
  REAL(r_std), PARAMETER :: cond_water = 0.6            !! Thermal conductivity of liquid water (W/m/K)
  REAL(r_std), PARAMETER :: cond_ice = 2.2              !! Thermal conductivity of ice (W/m/K)
  REAL(r_std), PARAMETER :: cond_solid = 2.32           !! Thermal conductivity of mineral soil particles (W/m/K)

  !! Time constant of long-term soil humidity (s) 
  REAL(r_std), PARAMETER :: lhf = 0.3336*1.E6           !! Latent heat of fusion (J/kg)

  INTEGER(i_std), PARAMETER :: nsnow=3                  !! Number of levels in the snow for explicit snow scheme   
  REAL(r_std), PARAMETER    :: XMD    = 28.9644E-3 
  REAL(r_std), PARAMETER    :: XBOLTZ      = 1.380658E-23 
  REAL(r_std), PARAMETER    :: XAVOGADRO   = 6.0221367E+23 
  REAL(r_std), PARAMETER    :: XRD    = XAVOGADRO * XBOLTZ / XMD 
  REAL(r_std), PARAMETER    :: XCPD   = 7.* XRD /2. 
  REAL(r_std), PARAMETER    :: phigeoth = 0.057 ! 0. DKtest 
  REAL(r_std), PARAMETER    :: thick_min_snow = .01 

  !! The maximum snow density and water holding characterisicts 
  REAL(r_std), SAVE         :: xrhosmax = 750.  ! (kg m-3) 
  REAL(r_std), SAVE         :: xwsnowholdmax1   = 0.03  ! (-) 
  REAL(r_std), SAVE         :: xwsnowholdmax2   = 0.10  ! (-) 
  REAL(r_std), SAVE         :: xsnowrhohold     = 200.0 ! (kg/m3) 
  REAL(r_std), SAVE         :: xrhosmin = 50. 
  REAL(r_std), PARAMETER    :: xci = 2.106e+3 
  REAL(r_std), PARAMETER    :: xrv = 6.0221367e+23 * 1.380658e-23 /18.0153e-3 

  !! ISBA-ES Critical snow depth at which snow grid thicknesses constant 
  REAL(r_std), PARAMETER    :: xsnowcritd = 0.03  ! (m) 

  !! The threshold of snow depth used for preventing numerical problem in thermal calculations
  REAL(r_std), PARAMETER    :: snowcritd_thermal = 0.01  ! (m)  
  
  !! ISBA-ES CROCUS (Pahaut 1976): snowfall density coefficients: 
  REAL(r_std), PARAMETER       :: snowfall_a_sn = 109.0  !! (kg/m3) 
  REAL(r_std), PARAMETER       :: snowfall_b_sn =   6.0  !! (kg/m3/K) 
  REAL(r_std), PARAMETER       :: snowfall_c_sn =  26.0  !! [kg/(m7/2 s1/2)] 

  REAL(r_std), PARAMETER       :: dgrain_new_max=  2.0e-4!! (m) : Maximum grain size of new snowfall 
  
  !! Used in explicitsnow to prevent numerical problems as snow becomes vanishingly thin. 
  REAL(r_std), PARAMETER                :: psnowdzmin = .0001   ! m 
  REAL(r_std), PARAMETER                :: xsnowdmin = .000001  ! m 

  REAL(r_std), PARAMETER                :: ph2o = 1000.         !! Water density [kg/m3] 
  
  ! ISBA-ES Thermal conductivity coefficients from Anderson (1976): 
  ! see Boone, Meteo-France/CNRM Note de Centre No. 70 (2002) 
  REAL(r_std), SAVE                     :: ZSNOWTHRMCOND1 = 0.02    ! [W/m/K] 
  REAL(r_std), SAVE                     :: ZSNOWTHRMCOND2 = 2.5E-6  ! [W m5/(kg2 K)] 
  
  ! ISBA-ES Thermal conductivity: Implicit vapor diffn effects 
  ! (sig only for new snow OR high altitudes) 
  ! from Sun et al. (1999): based on data from Jordan (1991) 
  ! see Boone, Meteo-France/CNRM Note de Centre No. 70 (2002) 
  ! 
  REAL(r_std), SAVE                       :: ZSNOWTHRMCOND_AVAP  = -0.06023 ! (W/m/K) 
  REAL(r_std), SAVE                       :: ZSNOWTHRMCOND_BVAP  = -2.5425  ! (W/m) 
  REAL(r_std), SAVE                       :: ZSNOWTHRMCOND_CVAP  = -289.99  ! (K) 
  
  REAL(r_std),SAVE :: xansmax = 0.85      !! Maxmimum snow albedo
  REAL(r_std),SAVE :: xansmin = 0.50      !! Miniumum snow albedo
  REAL(r_std),SAVE :: xans_todry = 0.008  !! Albedo decay rate for dry snow
  REAL(r_std),SAVE :: xans_t = 0.240      !! Albedo decay rate for wet snow

  ! ISBA-ES Thermal conductivity coefficients from Anderson (1976):
  ! see Boone, Meteo-France/CNRM Note de Centre No. 70 (2002)
  REAL(r_std), PARAMETER                  :: XP00 = 1.E5

  ! ISBA-ES Thermal conductivity: Implicit vapor diffn effects
  ! (sig only for new snow OR high altitudes)
  ! from Sun et al. (1999): based on data from Jordan (1991)
  ! see Boone, Meteo-France/CNRM Note de Centre No. 70 (2002)
  !
  REAL(r_std), SAVE          :: ZSNOWCMPCT_RHOD  = 150.0        !! (kg/m3)
  REAL(r_std), SAVE          :: ZSNOWCMPCT_ACM   = 2.8e-6       !! (1/s)
  REAL(r_std), SAVE          :: ZSNOWCMPCT_BCM   = 0.04         !! (1/K) 
  REAL(r_std), SAVE          :: ZSNOWCMPCT_CCM   = 460.         !! (m3/kg)
  REAL(r_std), SAVE          :: ZSNOWCMPCT_V0    = 3.7e7        !! (Pa/s) 
  REAL(r_std), SAVE          :: ZSNOWCMPCT_VT    = 0.081        !! (1/K)
  REAL(r_std), SAVE          :: ZSNOWCMPCT_VR    = 0.018        !! (m3/kg)
  !
  ! PARAMETERS USED BY ALBEDO
  !
  CHARACTER(LEN=30), SAVE                 :: albedo_type          !! This stores the type of albedo we are using
!$OMP THREADPRIVATE(albedo_type)
  LOGICAL, SAVE                           :: do_new_snow_albedo   !! If true, we use the snow albedo of CLM3 which 
                                                                  !! distinguishes between diffuse, direct, NIR, and VIS
!$OMP THREADPRIVATE(do_new_snow_albedo)
  INTEGER(i_std), PARAMETER               :: nlevels = 1          !! Number of levels in the canopy used in the albedo 
                                                                  !! calculation and the energy budget for the Pinty
                                                                  !! two-stream model
!$OMP THREADPRIVATE(nlevels)

  INTEGER(i_std), SAVE                    :: nlevels_photo        !! Number of levels in the canopy used in the photosynthesis
                                                                  !! routine per level dictacted by nlevels.  For example, if
                                                                  !! if nlevels = 2 and nlevels_photo = 3, the photosynthesis
                                                                  !! will be calculated for 2*3=6 total levels.
!$OMP THREADPRIVATE(nlevels_photo)
  INTEGER(i_std), SAVE                    :: nlevels_tot          !! Total number of levels, including photosythensis and energy
!$OMP THREADPRIVATE(nlevels_tot)

  INTEGER(i_std), SAVE                    :: nlev_top             !! Maximum number of canopy levels that are used to construct the "top"
                                                                  !! layer of the canopy. The top layer is used in the calculation
                                                                  !! transpiration.
!$OMP THREADPRIVATE(nlev_top) 

!  REAL(r_std), PARAMETER, DIMENSION (nlevels)    :: z_level = (/ 0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5/)                                              !! The height of the bottom of each canopy layer
  REAL(r_std), PARAMETER, DIMENSION (nlevels)    :: z_level = (/ 0.0 /)                                              !! The height of the bottom of each canopy layer
!  REAL(r_std), PARAMETER, DIMENSION (nlevels)    :: z_level = (/ 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0/)                                              !! The height of the bottom of each canopy layer
                                                                     !! @tex $(m)$ @endtex
!$OMP THREADPRIVATE(z_level)

  ! Parameters for the albedo optimization, only used with Pinty's scheme and more than one layer
  ! These are all somewhat arbitrary
  !
  REAL(r_std), SAVE                       ::  step_size_min       !! the value of the optimization step size below which
                                                                  !! we give up and say it will not converge
!$OMP THREADPRIVATE(step_size_min)
  REAL(r_std), SAVE                       ::  step_size_scale     !! the scale factor of the optimization step size
!$OMP THREADPRIVATE(step_size_scale)
  REAL(r_std), SAVE                       ::  converged_limit     !! the value of the optimization function below which
                                                                  !! the optimization is deemed converged
!$OMP THREADPRIVATE(converged_limit)
  INTEGER(i_std), SAVE                    ::  max_steps           !! the maximum number of optimization steps we try
!$OMP THREADPRIVATE(max_steps)

  !
  ! Parameters for determining the effective LAI for use in Pinty's albedo scheme
  !
  REAL(r_std), SAVE                       ::  laieff_solar_angle  !! the zenith angle of the sun which determines our effective LAI
                                                                  !! Pinty et al recommend a value of 60 degrees for this regadless of the true
                                                                  !! solar zenith angle
!$OMP THREADPRIVATE(laieff_solar_angle)
  REAL(r_std), SAVE                       ::  laieff_zero_cutoff   ! an arbitrary cutoff to prevent too low of values from being passed to
                                                                  ! routines in the calculation of the effective LAI
!$OMP THREADPRIVATE(laieff_zero_cutoff)
  INTEGER(i_std),PARAMETER                :: ndist_types=6       ! the number of distributions we need in the LAI effective routines
  INTEGER(i_std),PARAMETER                :: iheight=1         ! the tree height distribution
  INTEGER(i_std),PARAMETER                :: idiameter=2       ! the trunk diameter distribution
  INTEGER(i_std),PARAMETER                :: icnvol=3          ! the crown volume distribution
  INTEGER(i_std),PARAMETER                :: icnarea=4         ! the crown area distribution
  INTEGER(i_std),PARAMETER                :: icndiaver=5       ! the verticle crown diameter distribution
  INTEGER(i_std),PARAMETER                :: icndiahor=6       ! the horizontal crown diameter distribution

!+++++ DEBUG ++++
  REAL(r_std), SAVE                       ::  laieff_set_value_upper
!$OMP THREADPRIVATE(laieff_set_value_upper)
  REAL(r_std), SAVE                       ::  laieff_set_value_lower
!$OMP THREADPRIVATE(laieff_set_value_lower)
  REAL(r_std), SAVE                       ::  laieff_theta
!$OMP THREADPRIVATE(laieff_theta)
  ! These flags are all related to debugging.
  LOGICAL,PARAMETER                       :: ld_warn=.FALSE.      ! a flag to turn on various warnings 
  LOGICAL,PARAMETER                       :: ld_stop=.FALSE.      ! a flag to turn on some stop statements.
                                                                  ! Right now these are in allocation, and
                                                                  ! some of them were deemed to be
                                                                  ! not necessary to kill the code.
  LOGICAL,PARAMETER                       :: ld_forestry=.FALSE.  ! a flag to turn on debug statements
                                                                  ! related to forestry
  LOGICAL,PARAMETER                       :: ld_biomass=.FALSE.   ! a flag to turn on debug statements
                                                                  ! related to biomass
  LOGICAL,PARAMETER                       :: ld_albedo=.FALSE.    ! a flag to turn on debug statements
                                                                  ! related to albedo
  LOGICAL,PARAMETER                       :: ld_alloc=.FALSE.     ! a flag to turn on debug statements 
                                                                  ! in functional allocation
  LOGICAL,PARAMETER                       :: ld_trnov=.FALSE.     ! a flag to turn on debug statements
                                                                  ! in turnover prognostic
  LOGICAL,PARAMETER                       :: ld_lcc=.FALSE.       ! a flag to turn on debug statements
                                                                  ! in function land cover
  LOGICAL,PARAMETER                       :: ld_laieff=.FALSE.     ! a flag to turn on debug statements
                                                                  ! related to effective LAI
  LOGICAL,PARAMETER                       :: ld_massbal=.FALSE.   ! a flag to turn on debug statements
                                                                  ! related to mass balance closure
  LOGICAL,PARAMETER                       :: ld_hydrolarch=.FALSE.! a flag to turn on debug statements
  LOGICAL,PARAMETER                       :: ld_vmax=.FALSE.      ! a flag to turn on debug statements
  LOGICAL,PARAMETER                       :: ld_photo=.FALSE.     ! a flag to turn on debug statements
                                                                  ! in photosynthesis
  LOGICAL,PARAMETER                       :: ld_gstest=.FALSE.    ! a temperal flage to write gs/rveget
  LOGICAL,PARAMETER                       :: ld_pheno=.FALSE.     ! a flag to turn on debug statements
                                                                  ! in phenology 
  LOGICAL,PARAMETER                       :: ld_presc=.FALSE.     ! a flag to turn on debug statements
                                                                  ! in prescribe
  LOGICAL,PARAMETER                       :: ld_enerbil=.FALSE.   ! a flag to turn on debug statements
                                                                  ! in the energy budget
  LOGICAL,PARAMETER                       :: ld_coupled=.FALSE.   ! a flag to turn on debug statements
                                                                  ! in the coupling
  LOGICAL,PARAMETER                       :: ld_kill=.FALSE.      ! a flag to turn on debug statements
                                                                  ! related to plant mortality
  LOGICAL,PARAMETER                       :: ld_agec=.FALSE.      ! a flag to turn on debug statements
                                                                  ! related to age classes
  LOGICAL,PARAMETER                       :: ld_date=.FALSE.      ! writes time stamp to output file
                                                                  ! used in stomate
  LOGICAL,PARAMETER                       :: ld_wstress=.FALSE.   ! a flag to turn on relevant write 
                                                                  ! to debug the waterstress calculated
                                                                  ! in sechiba and used in stomate
                                                                  
  LOGICAL,PARAMETER                       :: ld_fake_height=.FALSE.  ! a flag to turn on the statements
                                                                     ! related to impose LAI and adjust the canopy 
                                                                     ! stucture by adjusting tree heigh in each CIRC class  
  ! JR flags
  !+++CHECK+++
  !If this flag really does what the comment text is saying 
  ! it should be defined in intersurf as an ok% flag because
  ! it strongly affects the flow of the model
  LOGICAL,PARAMETER                       :: jr_enerbil = .TRUE.    ! set this to TRUE to activate the new
                                                                    !  energy budget code
  !+++++++++++
  LOGICAL,PARAMETER                       :: james_write = .FALSE.  ! toggle for the write statements within
                                                                    !  enerbil

!+++++++++

  !
  ! Hydraulic architecture
  !
  REAL(r_std), SAVE, DIMENSION(2)         :: a_viscosity = (/0.556, 0.022/) !! Empirical parameters to adjust the resistance of fine
                                                                            !! root and sapwood to the temperature dependency of the
                                                                            !! viscosity of water Cochard et al 2000
!$OMP THREADPRIVATE(a_viscosity)
 

  !
  ! BVOC : Biogenic activity  for each age class
  !
  REAL(r_std), SAVE, DIMENSION(nleafages) :: iso_activity = (/0.5, 1.5, 1.5, 0.5/)     !! Biogenic activity for each 
                                                                                       !! age class : isoprene (unitless)
!$OMP THREADPRIVATE(iso_activity)
  REAL(r_std), SAVE, DIMENSION(nleafages) :: methanol_activity = (/1., 1., 0.5, 0.5/)  !! Biogenic activity for each
                                                                                       !! age class : methanol (unnitless)
!$OMP THREADPRIVATE(methanol_activity)

  !
  ! condveg.f90
  !

  ! 1. Scalar

  ! 1.1 Flags used inside the module

  LOGICAL, SAVE :: alb_bare_model = .FALSE. !! Switch for choosing values of bare soil 
                                            !! albedo (see header of subroutine)
                                            !! (true/false)
!$OMP THREADPRIVATE(alb_bare_model)
  LOGICAL, SAVE :: impaze = .FALSE.         !! Switch for choosing surface parameters
                                            !! (see header of subroutine).  
                                            !! (true/false)
!$OMP THREADPRIVATE(impaze)
  LOGICAL, SAVE :: z0cdrag_ave = .TRUE.     !! Chooses between two methods to calculate the 
                                            !! grid average of the roughness (see header of subroutine)   
                                            !! (true/false)
!$OMP THREADPRIVATE(z0cdrag_ave)
  ! 1.2 Others 

  REAL(r_std), SAVE :: z0_over_height = un/16.           !! Factor to calculate roughness height from 
                                                         !! vegetation height (unitless)   
!$OMP THREADPRIVATE(z0_over_height)
  REAL(r_std), SAVE :: height_displacement = 0.75        !! Factor to calculate the zero-plane displacement
                                                         !! height from vegetation height (m)
!$OMP THREADPRIVATE(height_displacement)
  REAL(r_std), SAVE :: z0_bare = 0.01                    !! bare soil roughness length (m)
!$OMP THREADPRIVATE(z0_bare)
  REAL(r_std), SAVE :: z0_ice = 0.001                    !! ice roughness length (m)
!$OMP THREADPRIVATE(z0_ice)
  REAL(r_std), SAVE :: tcst_snowa = 5.0                  !! Time constant of the albedo decay of snow (days)
!$OMP THREADPRIVATE(tcst_snowa)
  REAL(r_std), SAVE :: snowcri_alb = 10.                 !! Critical value for computation of snow albedo (cm)
!$OMP THREADPRIVATE(snowcri_alb)
  REAL(r_std), SAVE :: fixed_snow_albedo = undef_sechiba !! To choose a fixed snow albedo value (unitless)
!$OMP THREADPRIVATE(fixed_snow_albedo)
  REAL(r_std), SAVE :: z0_scal = 0.15                    !! Surface roughness height imposed (m)
!$OMP THREADPRIVATE(z0_scal)
  REAL(r_std), SAVE :: roughheight_scal = zero           !! Effective roughness Height depending on zero-plane 
                                                         !! displacement height (m) (imposed)
!$OMP THREADPRIVATE(roughheight_scal)
  REAL(r_std), SAVE :: emis_scal = 1.0                   !! Surface emissivity imposed (unitless)
!$OMP THREADPRIVATE(emis_scal)
  ! 2. Arrays

  REAL(r_std), SAVE, DIMENSION(2) :: alb_deadleaf = (/ .12, .35/)    !! albedo of dead leaves, VIS+NIR (unitless)
!$OMP THREADPRIVATE(alb_deadleaf)
  REAL(r_std), SAVE, DIMENSION(2) :: alb_ice = (/ .60, .20/)         !! albedo of ice, VIS+NIR (unitless)
!$OMP THREADPRIVATE(alb_ice)
  REAL(r_std), SAVE, DIMENSION(2) :: albedo_scal = (/ 0.25, 0.25 /)  !! Albedo values for visible and near-infrared 
                                                                     !! used imposed (unitless) 
!$OMP THREADPRIVATE(albedo_scal)
  REAL(r_std) , SAVE, DIMENSION(classnb) :: vis_dry = (/0.24,&
       &0.22, 0.20, 0.18, 0.16, 0.14, 0.12, 0.10, 0.27/)  !! Soil albedo values to soil colour classification:
                                                          !! dry soil albedo values in visible range
!$OMP THREADPRIVATE(vis_dry)
  REAL(r_std), SAVE, DIMENSION(classnb) :: nir_dry = (/0.48,&
       &0.44, 0.40, 0.36, 0.32, 0.28, 0.24, 0.20, 0.55/)  !! Soil albedo values to soil colour classification:
                                                          !! dry soil albedo values in near-infrared range 
!$OMP THREADPRIVATE(nir_dry)
  REAL(r_std), SAVE, DIMENSION(classnb) :: vis_wet = (/0.12,&
       &0.11, 0.10, 0.09, 0.08, 0.07, 0.06, 0.05, 0.15/)  !! Soil albedo values to soil colour classification:
                                                          !! wet soil albedo values in visible range 
!$OMP THREADPRIVATE(vis_wet)
  REAL(r_std), SAVE, DIMENSION(classnb) :: nir_wet = (/0.24,&
       &0.22, 0.20, 0.18, 0.16, 0.14, 0.12, 0.10, 0.31/)  !! Soil albedo values to soil colour classification:
                                                          !! wet soil albedo values in near-infrared range
!$OMP THREADPRIVATE(nir_wet)
  REAL(r_std), SAVE, DIMENSION(classnb) :: albsoil_vis = (/ &
       &0.18, 0.16, 0.16, 0.15, 0.12, 0.105, 0.09, 0.075, 0.25/)   !! Soil albedo values to soil colour classification:
                                                                   !! Averaged of wet and dry soil albedo values
                                                                   !! in visible and near-infrared range
!$OMP THREADPRIVATE(albsoil_vis) 
  REAL(r_std), SAVE, DIMENSION(classnb) :: albsoil_nir = (/ &
       &0.36, 0.34, 0.34, 0.33, 0.30, 0.25, 0.20, 0.15, 0.45/)  !! Soil albedo values to soil colour classification:
                                                                !! Averaged of wet and dry soil albedo values
                                                                !! in visible and near-infrared range
!$OMP THREADPRIVATE(albsoil_nir)
  REAL(r_std) :: alb_threshold = 0.0000000001_r_std      !! A threshold for the iteration of the
                                                          !! multilevel albedo.  Could be externalised.
                                                          !! Fairly arbitrary, although if a level has
                                                          !! no LAI the absorption often ends up being
                                                          !! equal to this value, so it should not
                                                          !! be high.
!$OMP THREADPRIVATE(alb_threshold)

  !
  ! diffuco.f90
  !

  ! 0. Constants

  REAL(r_std), PARAMETER :: Tetens_1 = 0.622         !! Ratio between molecular weight of water vapor and molecular weight  
                                                     !! of dry air (unitless)
  REAL(r_std), PARAMETER :: Tetens_2 = 0.378         !!
  REAL(r_std), PARAMETER :: ratio_H2O_to_CO2 = 1.6   !! Ratio of water vapor diffusivity to the CO2 diffusivity (unitless)
  REAL(r_std), PARAMETER :: mmol_to_m_1 = 0.0244     !!
  REAL(r_std), PARAMETER :: RG_to_PAR = 0.5          !!
  REAL(r_std), PARAMETER :: W_to_mmol = 4.6          !! W_to_mmol * RG_to_PAR = 2.3

  ! 1. Scalar

  INTEGER(i_std), SAVE :: nlai = 20             !! Number of LAI levels (unitless)
!$OMP THREADPRIVATE(nlai)
  LOGICAL, SAVE :: ldq_cdrag_from_gcm = .FALSE. !! Set to .TRUE. if you want q_cdrag coming from GCM
!$OMP THREADPRIVATE(ldq_cdrag_from_gcm)
  REAL(r_std), SAVE :: laimax = 12.             !! Maximal LAI used for splitting LAI into N layers (m^2.m^{-2})
!$OMP THREADPRIVATE(laimax)
  LOGICAL, SAVE :: downregulation_co2 = .FALSE.            !! Set to .TRUE. if you want CO2 downregulation.
!$OMP THREADPRIVATE(downregulation_co2)
  REAL(r_std), SAVE :: downregulation_co2_baselevel = 280. !! CO2 base level (ppm)
!$OMP THREADPRIVATE(downregulation_co2_baselevel)
  LOGICAL, SAVE :: lscale_lcc_nobio = .FALSE.   !! Set to .TRUE. if you want to scale new land cover maps
                                                !! (be careful with this.  Please check the documentation)
!$OMP THREADPRIVATE(lscale_lcc_nobio)
  LOGICAL, SAVE :: lignore_lcc_stops = .FALSE.  !! Set to .TRUE. if you want the code to keep running past
                                                !! a few places in land cover change where it would ordinarily
                                                !! stop.  Only use in very specific cases!
!$OMP THREADPRIVATE(lignore_lcc_stops)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: lai_level_depth = 0.15  !!
!$OMP THREADPRIVATE(lai_level_depth)
  REAL(r_std), SAVE, DIMENSION(6) :: dew_veg_poly_coeff = &            !! coefficients of the 5 degree polynomomial used
  & (/ 0.887773, 0.205673, 0.110112, 0.014843,  0.000824,  0.000017 /) !! in the equation of coeff_dew_veg
!$OMP THREADPRIVATE(dew_veg_poly_coeff)
  REAL(r_std), SAVE               :: Oi=210000.    !! Intercellular oxygen partial pressure (ubar)
!$OMP THREADPRIVATE(Oi)

  !
  ! slowproc.f90 
  !

  ! 1. Scalar

  INTEGER(i_std), SAVE :: veget_year_orig = 0        !!  first year for landuse (number)
!$OMP THREADPRIVATE(veget_year_orig)
  REAL(r_std), SAVE :: clayfraction_default = 0.2    !! Default value for clay fraction (0-1, unitless)
!$OMP THREADPRIVATE(clayfraction_default)
  REAL(r_std), SAVE :: min_vegfrac = 0.001           !! Minimal fraction of mesh a vegetation type can occupy (0-1, unitless)
!$OMP THREADPRIVATE(min_vegfrac)
  REAL(r_std), SAVE :: frac_nobio_fixed_test_1 = 0.0 !! Value for frac_nobio for tests in 0-dim simulations (0-1, unitless)
!$OMP THREADPRIVATE(frac_nobio_fixed_test_1)
  
  REAL(r_std), SAVE :: stempdiag_bid = 280.          !! only needed for an initial LAI if there is no restart file
!$OMP THREADPRIVATE(stempdiag_bid)


                           !-----------------------------!
                           !  STOMATE AND LPJ PARAMETERS !
                           !-----------------------------!


  !
  ! lpj_constraints.f90
  !
  
  ! 1. Scalar

  REAL(r_std), SAVE  :: too_long = 5.      !! longest sustainable time without 
                                           !! regeneration (vernalization) (years)
!$OMP THREADPRIVATE(too_long)


  !
  ! lpj_establish.f90
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: estab_max_tree = 0.12   !! Maximum tree establishment rate (0-1, unitless)
!$OMP THREADPRIVATE(estab_max_tree)
  REAL(r_std), SAVE :: estab_max_grass = 0.12  !! Maximum grass establishment rate (0-1, unitless)
!$OMP THREADPRIVATE(estab_max_grass)
  
  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: establish_scal_fact = 5.  !!
!$OMP THREADPRIVATE(establish_scal_fact)
  REAL(r_std), SAVE :: max_tree_coverage = 0.98  !! (0-1, unitless)
!$OMP THREADPRIVATE(max_tree_coverage)
  REAL(r_std), SAVE :: ind_0_estab = 0.2         !! = ind_0 * 10.
!$OMP THREADPRIVATE(ind_0_estab)


  !
  ! lpj_fire.f90
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: tau_fire = 30.           !! Time scale for memory of the fire index (days).
!$OMP THREADPRIVATE(tau_fire)
  REAL(r_std), SAVE :: litter_crit = 200.       !! Critical litter quantity for fire
                                                !! below which iginitions extinguish 
                                                !! @tex $(gC m^{-2})$ @endtex
!$OMP THREADPRIVATE(litter_crit)
  REAL(r_std), SAVE :: fire_resist_lignin = 0.5 !!
!$OMP THREADPRIVATE(fire_resist_lignin)
  ! 2. Arrays

  REAL(r_std), SAVE, DIMENSION(nparts) :: co2frac = &    !! The fraction of the different biomass 
       & (/ .95, .95, 0., 0.3, 0., 0., .95, .95, .95/)   !! compartments emitted to the atmosphere 
!$OMP THREADPRIVATE(co2frac)                             !! when burned (unitless, 0-1)  

  ! 3. Coefficients of equations

  REAL(r_std), SAVE, DIMENSION(3) :: bcfrac_coeff = (/ .3,  1.3,  88.2 /)         !! (unitless)
!$OMP THREADPRIVATE(bcfrac_coeff)
  REAL(r_std), SAVE, DIMENSION(4) :: firefrac_coeff = (/ 0.45, 0.8, 0.6, 0.13 /)  !! (unitless)
!$OMP THREADPRIVATE(firefrac_coeff)

  !
  ! lpj_gap.f90
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: ref_greff = 0.035         !! Asymptotic maximum mortality rate
                                                 !! @tex $(year^{-1})$ @endtex
!$OMP THREADPRIVATE(ref_greff)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: availability_fact = 0.1   !!
!$OMP THREADPRIVATE(availability_fact)

  !               
  ! lpj_light.f90 
  !              

  ! 1. Scalar
  
  LOGICAL, SAVE :: annual_increase = .TRUE. !! for diagnosis of fpc increase, compare today's fpc to last year's maximum (T) or
                                            !! to fpc of last time step (F)? (true/false)
!$OMP THREADPRIVATE(annual_increase)
  REAL(r_std), SAVE :: min_cover = 0.05     !! For trees, minimum fraction of crown area occupied
                                            !! (due to its branches etc.) (0-1, unitless)
                                            !! This means that only a small fraction of its crown area
                                            !! can be invaded by other trees.
!$OMP THREADPRIVATE(min_cover)


  !
  ! lpj_pftinout.f90 
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: min_avail = 0.01         !! minimum availability
!$OMP THREADPRIVATE(min_avail)
  REAL(r_std), SAVE :: ind_0 = 0.02             !! initial density of individuals
!$OMP THREADPRIVATE(ind_0)
  ! 3. Coefficients of equations
  
  REAL(r_std), SAVE :: RIP_time_min = 1.25      !! test whether the PFT has been eliminated lately (years)
!$OMP THREADPRIVATE(RIP_time_min)
  REAL(r_std), SAVE :: npp_longterm_init = 10.  !! Initialisation value for npp_longterm (gC.m^{-2}.year^{-1})
!$OMP THREADPRIVATE(npp_longterm_init)
  REAL(r_std), SAVE :: everywhere_init = 0.05   !!
!$OMP THREADPRIVATE(everywhere_init)


  !
  ! stomate_growth_res_lim.f90
  !

  ! 0. Constants

  REAL(r_std), PARAMETER :: max_possible_lai = 10. !! (m^2.m^{-2})
  REAL(r_std), PARAMETER :: Nlim_Q10 = 10.         !!

  ! 1. Scalar

  LOGICAL, SAVE :: ok_minres = .TRUE.              !! [DISPENSABLE] Do we try to reach a minimum reservoir even if
                                                   !! we are severely stressed? (true/false)
!$OMP THREADPRIVATE(ok_minres)
  REAL(r_std), SAVE :: tau_leafinit = 10.          !! Time required to develop a minimal LAI
                                                   !! using the carbohydrate reserve (days)
!$OMP THREADPRIVATE(tau_leafinit)
  REAL(r_std), SAVE :: reserve_time_tree = 30.     !! Maximum number of days during which
                                                   !! carbohydrate reserve may be used for 
                                                   !! trees (days)
!$OMP THREADPRIVATE(reserve_time_tree)
  REAL(r_std), SAVE :: reserve_time_grass = 20.    !! Maximum number of days during which
                                                   !! carbohydrate reserve may be used for 
                                                   !! grasses (days)
!$OMP THREADPRIVATE(reserve_time_grass)

  REAL(r_std), SAVE :: R0 = 0.3                    !! Default root allocation (0-1, unitless)
!$OMP THREADPRIVATE(R0)

  REAL(r_std), SAVE :: f_fruit = 0.1               !! Default fruit allocation (0-1, unitless)
!$OMP THREADPRIVATE(f_fruit)
  
  REAL(r_std), SAVE :: alloc_sap_above_grass = 1.0 !! fraction of sapwood allocation above ground
                                                   !! for grass (0-1, unitless)
!$OMP THREADPRIVATE(alloc_sap_above_grass)
  REAL(r_std), SAVE :: min_LtoLSR = 0.2            !! Prescribed lower bounds for leaf 
                                                   !! allocation (0-1, unitless)
!$OMP THREADPRIVATE(min_LtoLSR)
  REAL(r_std), SAVE :: max_LtoLSR = 0.5            !! Prescribed upper bounds for leaf 
                                                   !! allocation (0-1, unitless)
!$OMP THREADPRIVATE(max_LtoLSR)
  
  REAL(r_std), SAVE :: z_nitrogen = 0.2            !! Curvature of the root profile (m)
!$OMP THREADPRIVATE(z_nitrogen)
  
  REAL(r_std), SAVE :: tax_max = 0.8               !! Maximum fraction of allocatable biomass used 
                                                   !! for maintenance respiration (0-1, unitless)
!$OMP THREADPRIVATE(tax_max)

  ! 3. Coefficients of equations

!! Moved this to constantes_mtc
!!  REAL(r_std), SAVE :: lai_max_to_happy = 0.5      !! share of the maximum lai required to sustain
!!                                                   !! plant growth
!!$OMP THREADPRIVATE(lai_max_to_happy)
  
  REAL(r_std), SAVE :: Nlim_tref = 25.             !! (C)
!$OMP THREADPRIVATE(Nlim_tref)


  !
  ! stomate_growth_fun_all.f90
  !
  ! 1. Scalar  
  INTEGER(i_std), SAVE :: ncirc                    !! Number of circumference classes used to calculate C allocation
                                                   !! Used in prescribe.f90 and forestry.f90 - this mimics cohorts
!$OMP THREADPRIVATE(ncirc)

  INTEGER(i_std), SAVE :: nagec                    !! Number of age classes used to calculate C allocation
                                                   !! Used in forestry.f90 and lcchange.f90 - this mimics age classes
!$OMP THREADPRIVATE(nagec)
  LOGICAL, SAVE :: lbypass_cc                      !! Set to true for a temporary patch of a known bug, though the underlying
                                                   !! problem still must be fixed.
!$OMP THREADPRIVATE(lbypass_cc)

  REAL(r_std), SAVE :: min_water_stress = 0.1      !! Minimal value for wstress_fac (unitless, 0-1)
!$OMP THREADPRIVATE(min_water_stress)

  REAL(r_std), SAVE :: max_delta_KF = 0.1          !! Maximum change in KF from one time step to another (m)
                                                   !! This is a bit arbitrary. 
!$OMP THREADPRIVATE(max_delta_KF)

  REAL(r_std), SAVE :: evergreen_reserve = 0.05    !! Fraction of sapwood mass stored in the reserve pool of evergreen 
                                                   !! trees (unitless, 0-1) 
!$OMP THREADPRIVATE(evergreen_reserve)

  REAL(r_std), SAVE :: deciduous_reserve = 0.12    !! Fraction of sapwood mass stored in the reserve pool of deciduous 
                                                   !! trees during the growing season (unitless, 0-1) 
!$OMP THREADPRIVATE(deciduous_reserve)

  REAL(r_std), SAVE :: senescense_reserve = 0.15   !! Fraction of sapwood mass stored in the reserve pool of deciduous 
                                                   !! trees during senescense(unitless, 0-1) 
!$OMP THREADPRIVATE(senescense_reserve)

  REAL(r_std), SAVE :: labile_reserve = 60.        !! The lab_fac is divided by this value to obtain a new parameter
                                                   !! This new parameter is a fraction that is multiplied with the plant
                                                   !! biomass to obatin the optimal size of the labile pool. The dependency
                                                   !! on lab_fac is a nice feature but the whole parameterization is arbitrary
!$OMP THREADPRIVATE(labile_reserve)

  REAL(r_std), SAVE :: maint_from_labile = 0.2     !! Maintenance respiration should be positive. In case it is 
                                                   !! very low use ::maint_from_labile of the active labile carbon 
                                                   !! pool (gC m-2 dt-1)
!$OMP THREADPRIVATE(maint_from_labile)

  REAL(r_std), SAVE :: maint_from_gpp = 0.8        !! Some carbon needs to remain to support the growth, hence, 
                                                   !! respiration will be limited. In this case resp_maint 
                                                   !! (gC m-2 dt-1) should not be more than 80% (::maint_from_gpp) 
                                                   !! of the GPP (gC m-2 s-1)
!$OMP THREADPRIVATE(maint_from_gpp)
 

  REAL(r_std), SAVE :: sync_threshold = 0.0001     !! The threshold above which a warning is generated when the
                                                   !! total biomass is being compared to the sum of circ_class_biomass
!$OMP THREADPRIVATE(sync_threshold)

  !
  ! stomate_data.f90 
  !

  ! 1. Scalar 

  ! 1.1 climatic parameters 

  REAL(r_std), SAVE :: precip_crit = 100.        !! minimum precip, in (mm/year)
!$OMP THREADPRIVATE(precip_crit)
  REAL(r_std), SAVE :: gdd_crit_estab = 150.     !! minimum gdd for establishment of saplings
!$OMP THREADPRIVATE(gdd_crit_estab)
  REAL(r_std), SAVE :: fpc_crit = 0.95           !! critical fpc, needed for light competition and establishment (0-1, unitless)
!$OMP THREADPRIVATE(fpc_crit)

  ! 1.2 sapling characteristics

  REAL(r_std), SAVE :: alpha_grass = 0.5         !! alpha coefficient for grasses (unitless)
!$OMP THREADPRIVATE(alpha_grass)

  REAL(r_std), SAVE :: alpha_tree = 1.           !! alpha coefficient for trees (unitless)
!$OMP THREADPRIVATE(alpha_tree)

!!$  REAL(r_std), SAVE :: tune_c0_alloc = 2.3e-4   !! This parameter was tuned such that the ratio between root carbon and LAI is 
!!$                                                !! similar for grasses and trees. Only used for grasses and crops (thus NOT for 
!!$                                                !! trees)(unitless)
!!$!$OMP THREADPRIVATE(tune_c0_alloc)

!!$  REAL(r_std), SAVE :: struct_to_leaves = 0.05  !! Fraction of structural carbon in grass and crops as a share of the leaf 
!!$                                                !! carbon pool. Only used for grasses and crops (thus NOT for trees)
!!$                                                !! (unitless)
!!$!$OMP THREADPRIVATE(struct_to_leaves)

  REAL(r_std), SAVE :: labile_to_total = 0.01   !! Fraction of the labile pool in trees, grasses and crops as a share of the
                                                !! total carbon pool (accounting for the N-content of the different tissues).
                                                !! (unitless)
!$OMP THREADPRIVATE(labile_to_total)


  ! 1.3  time scales for phenology and other processes (in days)

  REAL(r_std), SAVE :: tau_hum_month = 20.               !! (days)       
!$OMP THREADPRIVATE(tau_hum_month)
  REAL(r_std), SAVE :: tau_hum_week = 7.                 !! (days)  
!$OMP THREADPRIVATE(tau_hum_week)
  REAL(r_std), SAVE :: tau_t2m_month = 20.               !! (days)      
!$OMP THREADPRIVATE(tau_t2m_month)
  REAL(r_std), SAVE :: tau_t2m_week = 7.                 !! (days)  
!$OMP THREADPRIVATE(tau_t2m_week)
  REAL(r_std), SAVE :: tau_tsoil_month = 20.             !! (days)     
!$OMP THREADPRIVATE(tau_tsoil_month)
  REAL(r_std), SAVE :: tau_soilhum_month = 20.           !! (days)     
!$OMP THREADPRIVATE(tau_soilhum_month)
  REAL(r_std), SAVE :: tau_gpp_week = 7.                 !! (days)  
!$OMP THREADPRIVATE(tau_gpp_week)
  REAL(r_std), SAVE :: tau_gdd = 40.                     !! (days)  
!$OMP THREADPRIVATE(tau_gdd)
  REAL(r_std), SAVE :: tau_ngd = 50.                     !! (days)  
!$OMP THREADPRIVATE(tau_ngd)
  REAL(r_std), SAVE :: coeff_tau_longterm = 3.           !! (unitless)
!$OMP THREADPRIVATE(coeff_tau_longterm)
  REAL(r_std), SAVE :: tau_longterm                      !! (days)  
!$OMP THREADPRIVATE(tau_longterm)
  REAL(r_std), SAVE :: tau_hum_growingseason_grass = 30. !! (days)  
!$OMP THREADPRIVATE(tau_hum_growingseason_grass)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: bm_sapl_carbres = 5.             !!
!$OMP THREADPRIVATE(bm_sapl_carbres)
  REAL(r_std), SAVE :: bm_sapl_sapabove = 0.5           !!
!$OMP THREADPRIVATE(bm_sapl_sapabove)
  REAL(r_std), SAVE :: bm_sapl_heartabove = 0.2         !! Stich et al 2003 has a value of 0.2 (2 is used in the trunk)
!$OMP THREADPRIVATE(bm_sapl_heartabove)
  REAL(r_std), SAVE :: bm_sapl_heartbelow = 0.2         !! Stich et al 2003 has a value of 0.2 (2 is used in the trunk
!$OMP THREADPRIVATE(bm_sapl_heartbelow)
  REAL(r_std), SAVE :: init_sapl_mass_leaf_nat = 0.1    !! LAI (m2 m-2) of a natural grassland at the time of its sewing. Similar to woody PFT's
                                                        !! the model starts from small plants rather than seeds.
!$OMP THREADPRIVATE(init_sapl_mass_leaf_nat)
  REAL(r_std), SAVE :: init_sapl_mass_leaf_agri = 1.    !! LAI (m2 m-2) of a agricultural grassland at the time of its sewing. Similar to woody PFT's
                                                        !! the model starts from small plants rather than seeds.
!$OMP THREADPRIVATE(init_sapl_mass_leaf_agri)
  REAL(r_std), SAVE :: init_sapl_mass_carbres = 5.      !!
!$OMP THREADPRIVATE(init_sapl_mass_carbres)
  REAL(r_std), SAVE :: init_sapl_mass_root = 0.1        !!
!$OMP THREADPRIVATE(init_sapl_mass_root)
  REAL(r_std), SAVE :: init_sapl_mass_fruit = 0.3       !!  
!$OMP THREADPRIVATE(init_sapl_mass_fruit)
  REAL(r_std), SAVE :: cn_sapl_init = 0.5               !!
!$OMP THREADPRIVATE(cn_sapl_init)
  REAL(r_std), SAVE :: migrate_tree = 10.*1.E3          !!
!$OMP THREADPRIVATE(migrate_tree)
  REAL(r_std), SAVE :: migrate_grass = 10.*1.E3         !!
!$OMP THREADPRIVATE(migrate_grass)

  REAL(r_std), SAVE :: lai_initmin_tree = 0.3           !! Minimum lai. If not available C is taken from the reserves to 
                                                        !! grow a canopy in phenology
!$OMP THREADPRIVATE(lai_initmin_tree)
  REAL(r_std), SAVE :: lai_initmin_grass = 0.1          !!
!$OMP THREADPRIVATE(lai_initmin_grass)

  REAL(r_std), SAVE, DIMENSION(2) :: dia_coeff = (/ 4., 0.5 /)            !!
!$OMP THREADPRIVATE(dia_coeff)
  REAL(r_std), SAVE, DIMENSION(2) :: maxdia_coeff =(/ 100., 0.01/)        !!
!$OMP THREADPRIVATE(maxdia_coeff)
  REAL(r_std), SAVE, DIMENSION(4) :: bm_sapl_leaf = (/ 4., 4., 0.8, 5./)  !!
!$OMP THREADPRIVATE(bm_sapl_leaf)

  !
  ! sapiens_forestry.f90
  !
  INTEGER(i_std), SAVE :: ndia_harvest                  !! The number of diameter classes used for 
                                                        !! the wood harvest pools.
!$OMP THREADPRIVATE(ndia_harvest) 
  REAL(r_std), SAVE      :: rdi_limit_upper=1            !! The parameters for self-thinning and yield come
                                                        !! from different data sets and are not necsassirly
                                                        !! fully consistent. The forestry code was written
                                                        !! such that it accounts for this consistency issue.
                                                        !! However, we still need a parameter that gives
                                                        !! us the upper_rdi_harvest in case the inconsistency
                                                        !! occurs.
!$OMP THREADPRIVATE(rdi_limit_upper)
  REAL(r_std), SAVE      :: max_harvest_dia             !! The largest diameter for the harvest pools to
                                                        !! keep track of harvested wood from forests.
!$OMP THREADPRIVATE(max_harvest_dia)
  INTEGER(i_std), SAVE   :: n_pai                       !! The number of years used for the cumulative
                                                        !! averages of the periodic annual increment.                      
!$OMP THREADPRIVATE(n_pai)
  LOGICAL, SAVE          :: use_litter_raking           !! If TRUE, this flag will simulate litter raking in 
                                                        !! in grid squares.  This has the effect of moving litter
                                                        !! once a year from forest PFTs to agricultural PFTs, if they
                                                        !! are present on this pixel.  If TRUE, you must also provide
                                                        !! a map with the litter demand so we know how much litter
                                                        !! to remove for each pixel.
!$OMP THREADPRIVATE(use_litter_raking)
  INTEGER(i_std), SAVE   :: management = 0              !! Use Diego Santarem's optimization for broadleaves
!$OMP THREADPRIVATE(management)
    LOGICAL, SAVE        :: fake                        !! The model run is fake model run: a given 
                                                        !! deltavol is forced clear at the first 
                                                        !! year (default = FALSE). !VB! Replace 
                                                        !! "fake" by "pseudo" in the description 
                                                        !! and in the code 
!$OMP THREADPRIVATE(fake)
    LOGICAL, SAVE        :: clearfirst                  !! Start model run with a clearcut (default 
                                                        !! = TRUE). 
!$OMP THREADPRIVATE(clearfirst)
    INTEGER(i_std), SAVE :: early_cut                   !! Flag determining what happens when 
                                                        !! density gets below dens_target (minima 
                                                        !! density threshold, see 
                                                        !! stomate_constants.f90): 0= nothing, 1 = 
                                                        !! revert to orch-std when density gets 
                                                        !! below minimal threshold, 2 = clearcut 
                                                        !! when density gets below minimal 
                                                        !! threshold 
!$OMP THREADPRIVATE(early_cut)
    INTEGER(i_std), SAVE :: itinerary                   !! Itinerary type for coppices: 1 = Popface 
                                                        !! experiment (Liberloo 2006), 3*6 years, 2 
                                                        !! = Orsay experiment (Pontailler 1999), 1 
                                                        !! + 2*5 years 
!$OMP THREADPRIVATE(itinerary)
    INTEGER(i_std), SAVE :: age_target_def              !! Age at which clearcut occurs no matter 
                                                        !! the density of the stand (years). This 
                                                        !! parameter is read from the run.def file 
                                                        !! (as others). According to Lanier (1994) 
                                                        !! and Bottcher (2008), it should most 
                                                        !! generally be between 100 and 200 years.
!$OMP THREADPRIVATE(age_target_def)
    INTEGER(i_std), SAVE :: ntrees_profit               !! The number of trees over which the average
                                                        !! height is calculated to determine if the
                                                        !! stand will be profitable to thin.
!$OMP THREADPRIVATE(ntrees_profit)

  INTEGER(i_std), SAVE   :: bavard_f                    !! If bavard_f=1, then a lot of "print", if 
                                                        !! bavard_f=2, even more.
!$OMP THREADPRIVATE(bavard_f)

  ! Variations for sensitivity analysis

  REAL(r_std), SAVE      :: ss_pipe_density = 1.        !! Sensitivity for pipe_density
!$OMP THREADPRIVATE(ss_pipe_density)
  REAL(r_std), SAVE      :: ss_selfth_curve = 1.        !! Sensitivity for selfth_curve
!$OMP THREADPRIVATE(ss_selfth_curve)
  REAL(r_std), SAVE      :: ss_sigma = 1.               !! Sensitivity for sigma
!$OMP THREADPRIVATE(ss_sigma)
  REAL(r_std), SAVE      :: ss_th_strat = 1.            !! Sensitivity for th_strat
!$OMP THREADPRIVATE(ss_th_strat)
  REAL(r_std), SAVE      :: ss_tau_spread = 1.          !! Sensitivity for tau_spread
!$OMP THREADPRIVATE(ss_tau_spread)
  REAL(r_std), SAVE      :: ss_lambda = 1.              !! Sensitivity for lambda
!$OMP THREADPRIVATE(ss_lambda)
  REAL(r_std), SAVE      :: ss_circ_bm = 1.             !! Sensitivity for circ_bm
!$OMP THREADPRIVATE(ss_circ_bm)
  REAL(r_std), SAVE      :: ss_height_circ = 1.         !! Sensitivity for height_circ
!$OMP THREADPRIVATE(ss_height_circ) 
  REAL(r_std), SAVE      :: ss_min_circ_init = 1.       !! Sensitivity for min_circ_init
!$OMP THREADPRIVATE(ss_min_circ_init)
  REAL(r_std), SAVE      :: ss_p_max = 1.               !! Sensitivity for p_max
!$OMP THREADPRIVATE(ss_p_max)
  LOGICAL, SAVE          :: lread_fm_map                !! A logical flag determining if we read
                                                        !! in the forest management strategy from a map.
!$OMP THREADPRIVATE(lread_fm_map)
  LOGICAL, SAVE          :: lread_species_change_map = .FALSE.   !! A logical flag determining if we read
                                                        !! in a map which changes species after a clearcut
!$OMP THREADPRIVATE(lread_species_change_map)
  LOGICAL, SAVE          :: lchange_species = .FALSE.   !! A logical flag determining if we change
                                                        !! species after a clearcut
!$OMP THREADPRIVATE(lchange_species)
  INTEGER, SAVE          :: species_change_force        !! This is the PFT number which is replanted after a 
                                                        !! clearcut, if such a thing is being done.
!$OMP THREADPRIVATE(species_change_force)

  !
  ! stomate_litter.f90 
  !

  ! 0. Constants

  REAL(r_std), PARAMETER :: Q10 = 10.               !!

  ! 1. Scalar

  REAL(r_std), SAVE :: z_decomp = 0.2               !!  Maximum depth for soil decomposer's activity (m)
!$OMP THREADPRIVATE(z_decomp)
  REAL(r_std), SAVE :: moistcont_min = 0.25         !! 
!$OMP THREADPRIVATE(moistcont_min)

  ! 2. Arrays

  REAL(r_std), SAVE :: frac_soil_struct_aa = 0.55   !! corresponding to frac_soil(istructural,iactive,iabove) 
!$OMP THREADPRIVATE(frac_soil_struct_aa)
  REAL(r_std), SAVE :: frac_soil_struct_ab = 0.45   !! corresponding to frac_soil(istructural,iactive,ibelow)
!$OMP THREADPRIVATE(frac_soil_struct_ab)
  REAL(r_std), SAVE :: frac_soil_struct_sa = 0.7    !! corresponding to frac_soil(istructural,islow,iabove)
!$OMP THREADPRIVATE(frac_soil_struct_sa)
  REAL(r_std), SAVE :: frac_soil_struct_sb = 0.7    !! corresponding to frac_soil(istructural,islow,ibelow)
!$OMP THREADPRIVATE(frac_soil_struct_sb)
  REAL(r_std), SAVE :: frac_soil_metab_aa = 0.45    !! corresponding to frac_soil(imetabolic,iactive,iabove)
!$OMP THREADPRIVATE(frac_soil_metab_aa)
  REAL(r_std), SAVE :: frac_soil_metab_ab = 0.45    !! corresponding to frac_soil(imetabolic,iactive,ibelow)
!$OMP THREADPRIVATE(frac_soil_metab_ab)
  REAL(r_std), SAVE, DIMENSION(nparts) :: CN = &    !! C/N ratio of each plant pool (0-100, unitless)
       & (/ 40., 40., 40., 40., 40., 40., 40., 40., 40./) 
!$OMP THREADPRIVATE(CN)
  REAL(r_std), SAVE, DIMENSION(nparts) :: LC = &    !! Lignin/C ratio of different plant parts (0,22-0,35, unitless)
       & (/ 0.22, 0.35, 0.35, 0.35, 0.35, 0.22, 0.22, 0.22, 0.22 /)
!$OMP THREADPRIVATE(LC)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: metabolic_ref_frac = 0.85    !! used by litter and soilcarbon (0-1, unitless)
!$OMP THREADPRIVATE(metabolic_ref_frac)
  REAL(r_std), SAVE :: metabolic_LN_ratio = 0.018   !! (0-1, unitless)   
!$OMP THREADPRIVATE(metabolic_LN_ratio)
  REAL(r_std), SAVE :: tau_metabolic = 0.066        !!
!$OMP THREADPRIVATE(tau_metabolic)
  REAL(r_std), SAVE :: tau_struct = 0.245           !!
!$OMP THREADPRIVATE(tau_struct)
  REAL(r_std), SAVE :: tau_woody = 0.75             !!
!$OMP THREADPRIVATE(tau_woody)
  REAL(r_std), SAVE :: soil_Q10 = 0.69              !!= ln 2
!$OMP THREADPRIVATE(soil_Q10)
  REAL(r_std), SAVE :: tsoil_ref = 30.              !!
!$OMP THREADPRIVATE(tsoil_ref)
  REAL(r_std), SAVE :: litter_struct_coef = 3.      !! 
!$OMP THREADPRIVATE(litter_struct_coef)
  REAL(r_std), SAVE, DIMENSION(3) :: moist_coeff = (/ -1.1,  2.4,  -0.29 /) !!
!$OMP THREADPRIVATE(moist_coeff)


  !
  ! stomate_lpj.f90
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: frac_turnover_daily = 0.55  !! (0-1, unitless)
!$OMP THREADPRIVATE(frac_turnover_daily)


  !
  ! stomate_phenology.f90
  !

  ! 1. Scalar

  LOGICAL, SAVE :: always_init = .FALSE.           !! take carbon from atmosphere if carbohydrate reserve too small? (true/false)
!$OMP THREADPRIVATE(always_init)
  REAL(r_std), SAVE :: min_growthinit_time = 300.  !! minimum time since last beginning of a growing season (days)
!$OMP THREADPRIVATE(min_growthinit_time)
  REAL(r_std), SAVE :: moiavail_always_tree = 1.0  !! moisture monthly availability above which moisture tendency doesn't matter
                                                   !!  - for trees (0-1, unitless)
!$OMP THREADPRIVATE(moiavail_always_tree)
  REAL(r_std), SAVE :: moiavail_always_grass = 0.6 !! moisture monthly availability above which moisture tendency doesn't matter
                                                   !! - for grass (0-1, unitless)
!$OMP THREADPRIVATE(moiavail_always_grass)
  REAL(r_std), SAVE :: t_always                    !! monthly temp. above which temp. tendency doesn't matter
!$OMP THREADPRIVATE(t_always)
  REAL(r_std), SAVE :: t_always_add = 10.          !! monthly temp. above which temp. tendency doesn't matter (C)
!$OMP THREADPRIVATE(t_always_add)

  ! 3. Coefficients of equations
  
  REAL(r_std), SAVE :: gddncd_ref = 603.           !!
!$OMP THREADPRIVATE(gddncd_ref)
  REAL(r_std), SAVE :: gddncd_curve = 0.0091       !!
!$OMP THREADPRIVATE(gddncd_curve)
  REAL(r_std), SAVE :: gddncd_offset = 64.         !!
!$OMP THREADPRIVATE(gddncd_offset)


  !
  ! stomate_prescribe.f90
  !

  ! 1. Scalar
    REAL(r_std), SAVE                       :: min_circ_init     !! Minimum initial circumferences of the 
                                                                 !! truncated exponential distribution (cm) 
!$OMP THREADPRIVATE(min_circ_init)
    REAL(r_std), SAVE                       :: frac_shoot_init   !! Frac_shoot_init is the same for the 
                                                                 !! initial distribution and is 
                                                                 !! parameterized based on Litton (2007) and 
                                                                 !! Mokany (2006). 
!$OMP THREADPRIVATE(frac_shoot_init)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: bm_sapl_rescale = 40.       !!
!$OMP THREADPRIVATE(bm_sapl_rescale)


  !
  ! stomate_resp.f90
  !

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: maint_resp_min_vmax = 0.3   !!
!$OMP THREADPRIVATE(maint_resp_min_vmax)
  
  REAL(r_std), SAVE :: maint_resp_coeff = 1.4      !!
!$OMP THREADPRIVATE(maint_resp_coeff)
  
  REAL(r_std), SAVE :: maint_resp_c = 1.           !!
!$OMP THREADPRIVATE(maint_resp_c)


  !
  ! stomate_soilcarbon.f90 
  !

  ! 2. Arrays 

  ! 2.1 frac_carb_coefficients

  REAL(r_std), SAVE :: frac_carb_ap = 0.004  !! from active pool: depends on clay content  (0-1, unitless)
                                             !! corresponding to frac_carb(:,iactive,ipassive)
!$OMP THREADPRIVATE(frac_carb_ap)
  REAL(r_std), SAVE :: frac_carb_sa = 0.42   !! from slow pool (0-1, unitless)
                                             !! corresponding to frac_carb(:,islow,iactive)
!$OMP THREADPRIVATE(frac_carb_sa)
  REAL(r_std), SAVE :: frac_carb_sp = 0.03   !! from slow pool (0-1, unitless) 
                                             !! corresponding to frac_carb(:,islow,ipassive)
!$OMP THREADPRIVATE(frac_carb_sp)
  REAL(r_std), SAVE :: frac_carb_pa = 0.45   !! from passive pool (0-1, unitless)
                                             !! corresponding to frac_carb(:,ipassive,iactive)
!$OMP THREADPRIVATE(frac_carb_pa)
  REAL(r_std), SAVE :: frac_carb_ps = 0.0    !! from passive pool (0-1, unitless)
                                             !! corresponding to frac_carb(:,ipassive,islow)
!$OMP THREADPRIVATE(frac_carb_ps)

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: active_to_pass_clay_frac = 0.68  !! (0-1, unitless)
!$OMP THREADPRIVATE(active_to_pass_clay_frac)
  !! residence times in carbon pools (days)
  REAL(r_std), SAVE :: carbon_tau_iactive = 0.149   !! residence times in active pool (days)
!$OMP THREADPRIVATE(carbon_tau_iactive)
  REAL(r_std), SAVE :: carbon_tau_islow = 5.48      !! residence times in slow pool (days)
!$OMP THREADPRIVATE(carbon_tau_islow)
  REAL(r_std), SAVE :: carbon_tau_ipassive = 241.   !! residence times in passive pool (days)
!$OMP THREADPRIVATE(carbon_tau_ipassive)
  REAL(r_std), SAVE, DIMENSION(3) :: flux_tot_coeff = (/ 1.2, 1.4, .75/)
!$OMP THREADPRIVATE(flux_tot_coeff)


  !
  ! stomate_turnover.f90
  !

  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: new_turnover_time_ref = 20. !!(days)
!$OMP THREADPRIVATE(new_turnover_time_ref)
  REAL(r_std), SAVE :: dt_turnover_time = 10.      !!(days)
!$OMP THREADPRIVATE(dt_turnover_time)
  REAL(r_std), SAVE :: leaf_age_crit_tref = 20.    !! (C)
!$OMP THREADPRIVATE(leaf_age_crit_tref)
  REAL(r_std), SAVE, DIMENSION(3) :: leaf_age_crit_coeff = (/ 1.5, 0.75, 10./) !! (unitless)
!$OMP THREADPRIVATE(leaf_age_crit_coeff)


  !
  ! stomate_vmax.f90
  !
 
  ! 1. Scalar

  REAL(r_std), SAVE :: vmax_offset = 0.3        !! minimum leaf efficiency (unitless)
!$OMP THREADPRIVATE(vmax_offset)
  REAL(r_std), SAVE :: leafage_firstmax = 0.03  !! relative leaf age at which efficiency
                                                !! reaches 1 (unitless)
!$OMP THREADPRIVATE(leafage_firstmax)
  REAL(r_std), SAVE :: leafage_lastmax = 0.5    !! relative leaf age at which efficiency
                                                !! falls below 1 (unitless)
!$OMP THREADPRIVATE(leafage_lastmax)
  REAL(r_std), SAVE :: leafage_old = 1.         !! relative leaf age at which efficiency
                                                !! reaches its minimum (vmax_offset) 
                                                !! (unitless)
!$OMP THREADPRIVATE(leafage_old)


  !
  ! stomate_season.f90 
  !

  ! 1. Scalar

  REAL(r_std), SAVE :: gppfrac_dormance = 0.2  !! report maximal GPP/GGP_max for dormance (0-1, unitless)
!$OMP THREADPRIVATE(gppfrac_dormance)
  REAL(r_std), SAVE :: tau_climatology = 20.   !! tau for "climatologic variables (years)
!$OMP THREADPRIVATE(tau_climatology)
  REAL(r_std), SAVE :: hvc1 = 0.019            !! parameters for herbivore activity (unitless)
!$OMP THREADPRIVATE(hvc1)
  REAL(r_std), SAVE :: hvc2 = 1.38             !! parameters for herbivore activity (unitless)
!$OMP THREADPRIVATE(hvc2)
  REAL(r_std), SAVE :: leaf_frac_hvc = 0.33    !! leaf fraction (0-1, unitless)
!$OMP THREADPRIVATE(leaf_frac_hvc)
  REAL(r_std), SAVE :: tlong_ref_max = 303.1   !! maximum reference long term temperature (K)
!$OMP THREADPRIVATE(tlong_ref_max)
  REAL(r_std), SAVE :: tlong_ref_min = 253.1   !! minimum reference long term temperature (K)
!$OMP THREADPRIVATE(tlong_ref_min)
  REAL(r_std), SAVE :: tune_waterstress = 1.   !! The calculated values of moiavail are too low to be used as
                                               !! multiplier for the allocation factors (::KF and ::LF). Hence,
                                               !! ::moiavail_daily is tuned by this factor to calculate 
                                               !! ::wstress_fac (unitless) 
!$OMP THREADPRIVATE(tune_waterstress)


  ! 3. Coefficients of equations

  REAL(r_std), SAVE :: ncd_max_year = 3.
!$OMP THREADPRIVATE(ncd_max_year)
  REAL(r_std), SAVE :: gdd_threshold = 5.
!$OMP THREADPRIVATE(gdd_threshold)
  REAL(r_std), SAVE :: green_age_ever = 2.
!$OMP THREADPRIVATE(green_age_ever)
  REAL(r_std), SAVE :: green_age_dec = 0.5
!$OMP THREADPRIVATE(green_age_dec)
  REAL(r_std), SAVE :: ngd_min_dormance = 90.
!$OMP THREADPRIVATE(ngd_min_dormance)



! stomate_io.f90

  REAL(r_std), SAVE :: mstemp = 13.9            !! Global Annual Mean Surface Temperature taken from 
                                                !! http://www.ncdc.noaa.gov/monitoring-references/faq/anomalies.php
!$OMP THREADPRIVATE(mstemp)




END MODULE constantes_var
